@@ -1,44 +1,49 @@
 from glob import iglob
-from pythautomata.base_types.state import State
 from re import findall, match, search
-from pythautomata.base_types.symbol import SymbolStr
-from pythautomata.base_types.alphabet import Alphabet
-from pythautomata.abstract.finite_automaton import FiniteAutomaton
-from pythautomata.exceptions.model_importing_error import ModelImportingError
 from typing import Any
 
+from pythautomata.abstract.finite_automaton import FiniteAutomaton
+from pythautomata.automata.deterministic_finite_automaton import \
+    DeterministicFiniteAutomaton
+from pythautomata.base_types.alphabet import Alphabet
+from pythautomata.base_types.state import State
+from pythautomata.base_types.symbol import SymbolStr
+from pythautomata.exceptions.model_importing_error import ModelImportingError
+
 
 class EncodedFileImporter:
 
     @staticmethod
-    def import_generated_automata(path:str=None):
-        if path is None:
-            path = "target_models"
+    def import_generated_automata(path: str = None):
+        raise NotImplementedError
+        # if path is None:
+        #     path = "target_models"
 
-        for fileName in iglob(path + "/**/*.ef", recursive=True):
-            file = open(fileName)
-            fileLines = file.readlines()
-            file.close()
+        # for fileName in iglob(path + "/**/*.ef", recursive=True):
+        #     file = open(fileName)
+        #     fileLines = file.readlines()
+        #     file.close()
 
-            alphabet = EncodedFileImporter._get_alphabet_from_data(fileLines)
-            del fileLines[:3]
-            statesByName, initialStates, currentIndex = EncodedFileImporter._get_states_from_data(
-                fileLines)
-            del fileLines[:currentIndex + 3]
-            EncodedFileImporter._get_transitions_from_data(
-                fileLines, alphabet, statesByName)
+        #     alphabet = EncodedFileImporter._get_alphabet_from_data(fileLines)
+        #     del fileLines[:3]
+        #     statesByName, initialStates, currentIndex = EncodedFileImporter._get_states_from_data(
+        #         fileLines)
+        #     del fileLines[:currentIndex + 3]
+        #     EncodedFileImporter._get_transitions_from_data(
+        #         fileLines, alphabet, statesByName)
 
-            modelNameResults = search(r"(?:\\.*\\([^\\]+) -)", fileName)
-            modelName = modelNameResults.group(1) if modelNameResults is not None else fileName
-            yield FiniteAutomaton(alphabet, initialStates,
-                                  set(statesByName.values()), modelName)
+        #     modelNameResults = search(r"(?:\\.*\\([^\\]+) -)", fileName)
+        #     modelName = modelNameResults.group(
+        #         1) if modelNameResults is not None else fileName
+        #     yield DeterministicFiniteAutomaton(alphabet, initialStates,
+        #                                        set(statesByName.values()), modelName)
 
     @staticmethod
     def _get_alphabet_from_data(fileLines: list) -> Alphabet:
         if not match(r"^(?:Alphabet: )\[(?:'([^']+)')(?:, (?:'([^']+)')+)*\]$", fileLines[0]):
             raise ModelImportingError()
         return Alphabet(frozenset(SymbolStr(symbol)
-                            for symbol in findall(r"(?:'([^']+)')", fileLines[0])))
+                                  for symbol in findall(r"(?:'([^']+)')", fileLines[0])))
 
     @staticmethod
     def _get_states_from_data(fileLines: list) -> tuple[dict[Any, State], frozenset[State], int]:
@@ -69,8 +74,9 @@ class EncodedFileImporter:
     def _get_transitions_from_data(fileLines: list, alphabet: Alphabet, statesByName: dict):
         currentIndex = 0
         while True:
-            originName = match(r"^(?:\"([^\"]+)\"):\n$", fileLines[currentIndex])
-            #TODO custom exception, hablar con franz
+            originName = match(
+                r"^(?:\"([^\"]+)\"):\n$", fileLines[currentIndex])
+            # TODO custom exception, hablar con franz
             assert originName is not None
             origin = statesByName[originName.group(1)]
 
